@@ -2,6 +2,8 @@ from starlette.config import Config
 from starlette.datastructures import Secret
 import boto3, os
 import pandas as pd
+from botocore import UNSIGNED
+from botocore.client import Config
 
 APP_VERSION = "0.0.1"
 APP_NAME = "BCI AVM"
@@ -30,10 +32,13 @@ load_dotenv()
 # print(config)
 # API_KEY: Secret = config("API_KEY", cast=Secret)
 
-ACCESS_KEY = os.environ["ACCESS_KEY"]
-SECRET_KEY = os.environ["SECRET_KEY"]
-BUCKET_NAME = os.environ["BUCKET_NAME"]
+# ACCESS_KEY = os.environ["ACCESS_KEY"]
+# SECRET_KEY = os.environ["SECRET_KEY"]
+# BUCKET_NAME = os.environ["BUCKET_NAME"]
+BUCKET_NAME="bciavm"
+
+# session = boto3.Session(aws_access_key_id=ACCESS_KEY, aws_secret_access_key=SECRET_KEY)
+# s3 = session.resource('s3')
+s3 = boto3.client('s3', config=Config(signature_version=UNSIGNED))
 
-session = boto3.Session(aws_access_key_id=ACCESS_KEY, aws_secret_access_key=SECRET_KEY)
-s3 = session.resource('s3')
 your_bucket = s3.Bucket(BUCKET_NAME)
